<?php

namespace Litecms\Videogallery\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Videogallery\Models\VideoGallery;

class VideoGalleryPolicy
{

    /**
     * Determine if the given user can view the video_gallery.
     *
     * @param UserPolicy $user
     * @param VideoGallery $video_gallery
     *
     * @return bool
     */
    public function view(UserPolicy $user, VideoGallery $video_gallery)
    {
        if ($user->canDo('videogallery.video_gallery.view') && $user->isAdmin()) {
            return true;
        }

        return $video_gallery->user_id == user_id() && $video_gallery->user_type == user_type();
    }

    /**
     * Determine if the given user can create a video_gallery.
     *
     * @param UserPolicy $user
     * @param VideoGallery $video_gallery
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('videogallery.video_gallery.create');
    }

    /**
     * Determine if the given user can update the given video_gallery.
     *
     * @param UserPolicy $user
     * @param VideoGallery $video_gallery
     *
     * @return bool
     */
    public function update(UserPolicy $user, VideoGallery $video_gallery)
    {
        if ($user->canDo('videogallery.video_gallery.edit') && $user->isAdmin()) {
            return true;
        }

        return $video_gallery->user_id == user_id() && $video_gallery->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given video_gallery.
     *
     * @param UserPolicy $user
     * @param VideoGallery $video_gallery
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, VideoGallery $video_gallery)
    {
        return $video_gallery->user_id == user_id() && $video_gallery->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given video_gallery.
     *
     * @param UserPolicy $user
     * @param VideoGallery $video_gallery
     *
     * @return bool
     */
    public function verify(UserPolicy $user, VideoGallery $video_gallery)
    {
        if ($user->canDo('videogallery.video_gallery.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given video_gallery.
     *
     * @param UserPolicy $user
     * @param VideoGallery $video_gallery
     *
     * @return bool
     */
    public function approve(UserPolicy $user, VideoGallery $video_gallery)
    {
        if ($user->canDo('videogallery.video_gallery.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
